# stripstats

This is a working statistics library.

## Installation

pip install stripstats

### Get Started

import stripstats

You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.
